==> projectal-2.0.3.tar.gz: projectal-2.0.3/projectal/entities/department.py <==
from projectal.entity import Entity
from projectal.linkers import *
from projectal import api


class Department(Entity, StaffLinker, DepartmentLinker):
    """
    Implementation of the [Department](https://projectal.com/docs/latest/#tag/Department) API.
    """
    _path = 'department'
    _name = 'DEPARTMENT'

    @staticmethod
    def tree(uuId=None, level=None, active_staff=True, inactive_staff=True):
        """
        Return department list in tree format

        `uuId`: Of a department. If no department is requested, the full
        department chart is returned (default: `None`)

        `level`: If `True`, only returns the top level of the
        hierarchy (default: `False`).

        `active_staff`: If `True`, includes the list of staff in each
        department who are considered 'active' (i.e, today is within
        their start and end dates) (default: `True`)

        'inactive_staff`: If `True`, includes the list of staff in each
        department who are considered 'inactive' (i.e, today is outside
        their start and end dates) (default: `True`)
        """
        url = '/api/department/tree?'
        params = []
        params.append('uuId={}'.format(uuId)) if uuId else None
        params.append('level=true') if level else None
        params.append('activeStaff={}'.format('true' if active_staff else 'false'))
        params.append('inactiveStaff={}'.format('true' if inactive_staff else 'false'))
        url += '&'.join(params)

        return api.get(url)

==> projectal-3.0.0.tar.gz: projectal-3.0.0/projectal/entities/department.py <==
from projectal.entity import Entity
from projectal import api
from projectal.linkers import *


class Department(Entity, StaffLinker, DepartmentLinker, CompanyLinker, NoteLinker):
    """
    Implementation of the [Department](https://projectal.com/docs/latest/#tag/Department) API.
    """
    _path = 'department'
    _name = 'department'
    _links = [StaffLinker, DepartmentLinker, NoteLinker]
    _links_reverse = [CompanyLinker]

    @staticmethod
    def tree(holder=None, level=None, active_staff=True, inactive_staff=True,
             generic_staff=False):
        """
        Return department list in tree format

        `holder`: Project, Company, or Staff. If None, the full department chart
        is returned (default: `None`)

        `level`: If `True`, only returns the top level of the
        hierarchy (default: `False`)

        `active_staff`: If `True`, includes the list of staff in each
        department who are considered 'active' (i.e, today is within
        their start and end dates) (default: `True`)

        'inactive_staff`: If `True`, includes the list of staff in each
        department who are considered 'inactive' (i.e, today is outside
        their start and end dates) (default: `True`)

        `generic_staff`: Include generic staff in results
        """
        url = '/api/department/tree?'
        params = []
        params.append('uuId={}'.format(holder['uuId'])) if holder else None
        params.append('level=true') if level else None
        params.append('activeStaff={}'.format('true' if active_staff else 'false'))
        params.append('inactiveStaff={}'.format('true' if inactive_staff else 'false'))
        params.append('genericStaff={}'.format('true' if generic_staff else 'false'))
        url += '&'.join(params)

        return api.get(url)
